@@ -1,5 +1,5 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,7 @@
 
 static const char * const Program_name = "Arg_parser";
 static const char * const program_name = "arg_parser";
-static const char * const program_year = "2012";
+static const char * const program_year = "2013";
 static const char * invocation_name = 0;
 
 
@@ -80,7 +80,7 @@ void show_error( const char * const msg, const int errcode, const char help )
       fprintf( stderr, ": %s", strerror( errcode ) );
     fprintf( stderr, "\n" );
     }
-  if( help && invocation_name && invocation_name[0] )
+  if( help )
     fprintf( stderr, "Try '%s --help' for more information.\n",
              invocation_name );
   }
