@@ -1,5 +1,5 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@ namespace {
 
 const char * const Program_name = "Arg_parser";
 const char * const program_name = "arg_parser";
-const char * const program_year = "2012";
+const char * const program_year = "2013";
 const char * invocation_name = 0;
 
 
@@ -85,7 +85,7 @@ void show_error( const char * const msg, const int errcode = 0,
       std::fprintf( stderr, ": %s", std::strerror( errcode ) );
     std::fprintf( stderr, "\n" );
     }
-  if( help && invocation_name && invocation_name[0] )
+  if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
                   invocation_name );
   }
